tlslite.utils.OpenSSL_TripleDES.OpenSSL_TripleDES

Package tlslite :: Package utils :: Module OpenSSL_TripleDES :: Class OpenSSL_TripleDES |
[show private | hide private]
[frames | no frames]

## Class OpenSSL_TripleDES

    TripleDES --+
                |
               OpenSSL_TripleDES

Method Summary
| `__init__(self, key, mode, IV)`
| `decrypt(self, ciphertext)`
| `encrypt(self, plaintext)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net